QualifierProvider<T> class

Inheritance

Constructors

QualifierProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllInstances() List<T>
override
getInstance({String? qualifier}) → T
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provideAll() List<T>
override
register({String? qualifier, bool? singleton, required T builder()}) → dynamic
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited