Module class abstract

Constructors

Module(ScopedState<StatefulWidget> _scopedState)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

inject<E>({String? qualifier}) → E
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onProvide() → void
provide<E>(E builder(), {String? qualifier, bool? singleton}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited